@@ -53,6 +53,7 @@ from huggingface_hub.inference._providers.replicate import (
 from huggingface_hub.inference._providers.sambanova import SambanovaConversationalTask, SambanovaFeatureExtractionTask
 from huggingface_hub.inference._providers.scaleway import ScalewayConversationalTask, ScalewayFeatureExtractionTask
 from huggingface_hub.inference._providers.together import TogetherTextToImageTask
+from huggingface_hub.inference._providers.zai_org import ZaiConversationalTask
 
 from .testing_utils import assert_in_logs
 
@@ -916,6 +917,31 @@ class TestHFInferenceProvider:
         else:
             _check_supported_task("test-model", task)
 
+    def test_prepare_request_from_binary_data(self, mocker, tmp_path):
+        helper = HFInferenceBinaryInputTask("image-classification")
+
+        mock_model_info = mocker.Mock(pipeline_tag="image-classification", tags=[])
+        mocker.patch("huggingface_hub.hf_api.HfApi.model_info", return_value=mock_model_info)
+
+        image_path = tmp_path / "image.jpg"
+        image_path.write_bytes(b"dummy binary input")
+
+        request = helper.prepare_request(
+            inputs=image_path,
+            parameters={},
+            headers={},
+            model="microsoft/resnet-50",
+            api_key="hf_test_token",
+            extra_payload=None,
+        )
+        assert request.url == "https://router.huggingface.co/hf-inference/models/microsoft/resnet-50"
+        assert request.task == "image-classification"
+        assert request.model == "microsoft/resnet-50"
+        assert request.json is None
+        assert isinstance(request.data, bytes)
+        assert request.headers["authorization"] == "Bearer hf_test_token"
+        assert request.headers["content-type"] == "image/jpeg"  # based on filename
+
 
 class TestHyperbolicProvider:
     def test_prepare_route(self):
@@ -1387,6 +1413,28 @@ class TestTogetherProvider:
         assert response == b"image_bytes"
 
 
+class TestZaiProvider:
+    def test_prepare_route(self):
+        helper = ZaiConversationalTask()
+        route = helper._prepare_route("test-model", "zai_token")
+        assert route == "/api/paas/v4/chat/completions"
+
+    def test_prepare_headers(self):
+        helper = ZaiConversationalTask()
+        headers = helper._prepare_headers({}, "test_key")
+        assert headers["Accept-Language"] == "en-US,en"
+
+    def test_prepare_url(self):
+        helper = ZaiConversationalTask()
+        assert helper.task == "conversational"
+        url = helper._prepare_url("zai_token", "test-model")
+        assert url == "https://api.z.ai/api/paas/v4/chat/completions"
+
+        # Test with HF token (should route through HF proxy)
+        url = helper._prepare_url("hf_token", "test-model")
+        assert url.startswith("https://router.huggingface.co/zai-org")
+
+
 class TestBaseConversationalTask:
     def test_prepare_route(self):
         helper = BaseConversationalTask(provider="test-provider", base_url="https://api.test.com")
